@@ -25,11 +25,11 @@ Pg::Explain::Hinter::Hint - Single hint for Pg::Explain plan
 
 =head1 VERSION
 
-Version 2.0
+Version 2.10
 
 =cut
 
-our $VERSION = '2.0';
+our $VERSION = '2.10';
 
 =head1 SYNOPSIS
 
@@ -133,6 +133,30 @@ Details:
 
 =back
 
+=head2 INDEXABLE_SEQSCAN_MULTI_EQUAL_AND
+
+Node that the hint is for us using sequential scan, and it should be possible to add index(es) to make it go faster.
+
+This happens only for scans that have multiple equality checks joined with AND operator, like:
+
+=over
+
+=item * a = 1 and b = 2
+
+=item * x = 'abc' and z = 12
+
+=back
+
+Details are arrayref where each element is hashref with two keys:
+
+=over
+
+=item * column : column name that was checked
+
+=item * value : the value that the check was using
+
+=back
+
 =head1 AUTHOR
 
 hubert depesz lubaczewski, C<< <depesz at depesz.com> >>
@@ -149,7 +173,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008-2021 hubert depesz lubaczewski, all rights reserved.
+Copyright 2008-2023 hubert depesz lubaczewski, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
